@@ -47,6 +47,12 @@ except ImportError:
     print("Mongo Datasource is not available by default. If you wish to use it, please install mindsdb_native[extra_data_sources]")
     MongoDS = None
 
+try:
+    from mindsdb_native.libs.data_sources.aws_athena_ds import AthenaDS
+except ImportError:
+    print("Athena Datasource is not available by default. If you wish to use it, please install mindsdb_native[extra_data_sources]")
+    AthenaDS = None
+
 try:
     from mindsdb_native.libs.data_sources.snowflake_ds import SnowflakeDS
 except ImportError:
