@@ -14,9 +14,11 @@ from mindsdb_native.libs.controllers.transaction import AnalyseTransaction
 from mindsdb_native.libs.controllers.predictor import _get_memory_optimizations, _prepare_sample_settings, Predictor
 from mindsdb_native.libs.helpers.multi_data_source import getDS
 from mindsdb_native.libs.helpers.general_helpers import load_lmd, load_hmd
-from mindsdb_native.libs.constants.mindsdb import (MODEL_STATUS_TRAINED,
-                                                   MODEL_STATUS_ERROR,
-                                                   TRANSACTION_ANALYSE)
+from mindsdb_native.libs.constants.mindsdb import (
+    MODEL_STATUS_TRAINED,
+    MODEL_STATUS_ERROR,
+    TRANSACTION_ANALYSE
+)
 from mindsdb_native.libs.helpers.locking import MDBLock
 
 
@@ -133,17 +135,6 @@ def export_predictor(model_name):
                 full_path = os.path.join(CONFIG.MINDSDB_STORAGE_PATH, model_name, file_name)
                 zip_fp.write(full_path, os.path.basename(full_path))
 
-            # If the backend is ludwig, save the ludwig files
-            try:
-                ludwig_model_path = os.path.join(CONFIG.MINDSDB_STORAGE_PATH, model_name, 'ludwig_data')
-                for root, dirs, files in os.walk(ludwig_model_path):
-                    for file in files:
-                        full_path = os.path.join(root, file)
-                        zip_fp.write(full_path,
-                                    full_path[len(CONFIG.MINDSDB_STORAGE_PATH):])
-            except Exception:
-                pass
-
         print(f'Exported model to {storage_file}')
 
 
@@ -162,15 +153,12 @@ def rename_model(old_model_name, new_model_name):
         if old_model_name == new_model_name:
             return True
 
-        moved_a_backend = False
-        for extension in ['lightwood_data', 'ludwig_data']:
+        try:
             shutil.move(
-                os.path.join(CONFIG.MINDSDB_STORAGE_PATH, old_model_name, extension),
-                os.path.join(CONFIG.MINDSDB_STORAGE_PATH, new_model_name, extension)
+                os.path.join(CONFIG.MINDSDB_STORAGE_PATH, old_model_name, 'lightwood_data'),
+                os.path.join(CONFIG.MINDSDB_STORAGE_PATH, new_model_name, 'lightwood_data')
             )
-            moved_a_backend = True
-
-        if not moved_a_backend:
+        except Exception:
             return False
 
         lmd = load_lmd(os.path.join(CONFIG.MINDSDB_STORAGE_PATH, old_model_name, 'light_model_metadata.pickle'))
@@ -179,22 +167,10 @@ def rename_model(old_model_name, new_model_name):
         lmd['name'] = new_model_name
         hmd['name'] = new_model_name
 
-        renamed_one_backend = False
-        try:
-            lmd['ludwig_data']['ludwig_save_path'] = lmd['ludwig_data'][
-                'ludwig_save_path'].replace(old_model_name, new_model_name)
-            renamed_one_backend = True
-        except Exception:
-            pass
-
         try:
             lmd['lightwood_data']['save_path'] = lmd['lightwood_data'][
                 'save_path'].replace(old_model_name, new_model_name)
-            renamed_one_backend = True
         except Exception:
-            pass
-
-        if not renamed_one_backend:
             return False
 
         with open(os.path.join(CONFIG.MINDSDB_STORAGE_PATH,
@@ -229,11 +205,6 @@ def delete_model(model_name):
         except Exception:
             pass
 
-        try:
-            shutil.rmtree(lmd['ludwig_data']['ludwig_save_path'])
-        except Exception:
-            pass
-
         shutil.rmtree(os.path.join(CONFIG.MINDSDB_STORAGE_PATH, model_name))
 
 
@@ -268,9 +239,6 @@ def import_model(model_archive_path, new_name=None):
     )
 
     with MDBLock('exclusive', 'detele_' + lmd['name']):
-        if 'ludwig_data' in lmd and 'ludwig_save_path' in lmd['ludwig_data']:
-            lmd['ludwig_data']['ludwig_save_path'] = os.path.join(CONFIG.MINDSDB_STORAGE_PATH, lmd['name'], 'ludwig_data')
-
         if 'lightwood_data' in lmd and 'save_path' in lmd['lightwood_data']:
             lmd['lightwood_data']['save_path'] = os.path.join(CONFIG.MINDSDB_STORAGE_PATH, lmd['name'], 'lightwood_data')
 
