@@ -33,7 +33,7 @@ class GCSDS(DataSource):
             gc_client.download_blob_to_file(blob, fw)
 
         file_ds = FileDS(self.tmp_file_name)
-        return file_ds._df, file_ds._col_map
+        return file_ds.df, file_ds._col_map
 
     def _cleanup(self):
         os.remove(self.tmp_file_name)
