@@ -1,15 +1,15 @@
 import os
 import sys
+import json
 import platform
 import re
 import pickle
 import requests
+import numpy as np
 from pathlib import Path
 import uuid
 from contextlib import contextmanager
 
-import os
-import sys
 from sklearn.metrics import (
     balanced_accuracy_score,
     accuracy_score,
@@ -23,6 +23,24 @@ from mindsdb_native.libs.data_types.mindsdb_logger import log
 from mindsdb_native.libs.constants.mindsdb import *
 
 
+class NumpyJSONEncoder(json.JSONEncoder):
+    """
+    Use this encoder to avoid
+    "TypeError: Object of type float32 is not JSON serializable"
+
+    Example:
+    x = np.float32(5)
+    json.dumps(x, cls=NumpyJSONEncoder)
+    """
+    def default(self, obj):
+        if isinstance(obj, np.ndarray):
+            return obj.tolist()
+        elif isinstance(obj, (np.float, np.float32, np.float64)):
+            return float(obj)
+        else:
+            return super().default(obj)
+
+
 def check_for_updates():
     """
     Check for updates of mindsdb
@@ -182,12 +200,13 @@ def evaluate_generic_accuracy(column, predictions, true_values, **kwargs):
 def evaluate_array_accuracy(column, predictions, true_values, **kwargs):
     accuracy = 0
     true_values = list(true_values)
+    acc_f = balanced_accuracy_score if kwargs['categorical'] else r2_score
     for i in range(len(predictions[column])):
         if isinstance(true_values[i],list):
-            accuracy += r2_score(predictions[column][i],true_values[i])
+            accuracy += acc_f(predictions[column][i],true_values[i])
         else:
             # For the T+1 usecase
-            accuracy = r2_score([x[0] for x in predictions[column]], true_values)
+            accuracy = acc_f([x[0] for x in predictions[column]], true_values)
             return accuracy
 
     accuracy = accuracy/len(predictions[column])
@@ -208,6 +227,8 @@ def evaluate_accuracy(predictions, data_frame, col_stats, output_columns, backen
                 evaluator = evaluate_classification_accuracy
         elif col_type == DATA_TYPES.SEQUENTIAL:
             evaluator = evaluate_array_accuracy
+            kwargs['categorical'] = True if DATA_TYPES.CATEGORICAL in \
+                                            col_stats[column]['typing'].get('data_type_dist', []) else False
         else:
             evaluator = evaluate_generic_accuracy
         column_score = evaluator(
